Exclude o.e.d.c.sqm.server.ui's version v201202021103 and o.e.d.e.msft.sqlserver.dbdefinition's version v201201240505 in list of plugins with potential version issue
diff --git a/plugins/org.eclipse.datatools.releng.builder/extras/CheckDTP_PotentialVersionIssue.sh b/plugins/org.eclipse.datatools.releng.builder/extras/CheckDTP_PotentialVersionIssue.sh
index 4edaee7..b58c53d 100644
--- a/plugins/org.eclipse.datatools.releng.builder/extras/CheckDTP_PotentialVersionIssue.sh
+++ b/plugins/org.eclipse.datatools.releng.builder/extras/CheckDTP_PotentialVersionIssue.sh
@@ -51,9 +51,9 @@
 		echo "$PluginName: no change since last release"
 		echo "$PluginName" >> nochange.txt
 	elif [ "$MajorVersion" = "$MajorVersion2" ]; then
 		#Exclude current bundle version timestamp of v201203291105 in list of plugins with potential version issue
 		#Someone checked in an incorrect change in Head (for 1.10) for oe.d.c.oda.profile, but has since been reverted, so we should not increment the version number
-		if ( echo "$TimeStamp2" | grep v201203291105 >/dev/null ); then
+		if ( echo "$TimeStamp2" | grep v201203291105 >/dev/null ) || ( echo "$TimeStamp2" | grep v201202021103 >/dev/null ) || ( echo "$TimeStamp2" | grep v201201240505 >/dev/null ); then
 			echo "$PluginName: Exclude in list of plugins with potential version issue"
                         echo "$PluginName" >> excludechange.txt
                         echo "Last_Release_Version: $MajorVersion.$TimeStamp" >> excludechange.txt
@@ -51,9 +51,9 @@
 		echo "$PluginName" >> nochange.txt
 	elif [ "$MajorVersion" = "$MajorVersion2" ]; then
-		#Exclude current bundle version timestamp of v201203291105 in list of plugins with potential version issue
+		#Exclude current bundle version timestamp of v201203291105,v201202021103,v201201240505 in list of plugins with potential version issue
 		#Someone checked in an incorrect change in Head (for 1.10) for oe.d.c.oda.profile, but has since been reverted, so we should not increment the version number